%--------------------------------------------------------------------------
%   Demonstrate the use of FFMaintenanceSim to analyze disturbance effects.
%--------------------------------------------------------------------------

addpath(fullfile(fileparts(which(mfilename)),'support'));

%--------------------------------------------------------------------------
%	Copyright 2008 Princeton Satellite Systems, Inc. All rights reserved.
%--------------------------------------------------------------------------


%% Initialize simulation data structure
s = FFMaintenanceTests;

%% Set initial state to 500 m leader follower
sma = s.el0(1);   % semi major axis
s.dEl0 = zeros(1,6);
s.dEl0(2) = .5/sma;

%% Set formations goals to be 250 m relative ellipse
s.goals.y0 = 0;      % center of ellipse in along-track direction
s.goals.aE = .25;    % size of ellipse
s.goals.beta = 0;    % phase on ellipse at equator crossing
s.goals.zInc = .1;   % cross-track oscillation (inclination difference)
s.goals.zLan = -.1;  % cross-track oscillation (right ascension difference)

%% Simulate 
d = FFMaintenanceSim(s);

%% Add noise
s.noise(3) = 1e-1;   % 10 cm  relative position noise
s.noise(4) = 1e-2;   % 10 mm/s relative navigation noise

%% Simulate with noise
d2 = FFMaintenanceSim(s);

%% Add differential drag
s.noise(1:4)   = 0;     % reset to zero noise
s.distOpt(2)   = 1;     % flag to model differential drag
s.area
s.area(2) = 10;         % set area differential to 5 sq. meters.

%% Simulate with differential drag
d3 = FFMaintenanceSim(s);

%% View results...
FFMaintenancePlotter( d );
% repeat for d2, d3 as desired

figure
stairs(d.dVt,cumsum(Mag(d.dV))*1e3), hold on, 
stairs(d2.dVt,cumsum(Mag(d2.dV))*1e3,'g'),
stairs(d3.dVt,cumsum(Mag(d3.dV))*1e3,'r'), 
legend('Reconfigure','Reconfigure with Noise','Reconfigure with Drag',0)
xlabel('Time [sec]'), ylabel('Delta-V [m/s]')
title('Cumulative Delta-V')
grid on

figure
title('Tracking Error')
plot(d.time,Mag(d.rH_des-d.rH)*1e3),  hold on
plot(d2.time,Mag(d2.rH_des-d2.rH)*1e3,'g')
plot(d3.time,Mag(d3.rH_des-d3.rH)*1e3,'r')
legend('Reconfigure','Reconfigure with Noise','Reconfigure with Drag',0)
xlabel('Time [sec]'), ylabel('Pos. Error [m]')
grid on




