
%-------------------------------------------------------------------------------
%   Returns data associated with various test runs for "FFMaintenanceSim".
%
%   Each case has specific data associated with it. You may add new cases 
%   to this function. This enables you to reproduce specific scenarios.
%
%   Use the output of this function as the input to "FFMaintenanceSim".
%-------------------------------------------------------------------------------
%   Usage:
%   simOptions = FFMaintenanceTests( name );
%   simOptions = FFMaintenanceTests; % print cases, return default options
%-------------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   name          (:)   Name of the stored test case
%
%   -------
%   Outputs
%   -------
%   simOptions    (.)   Data structure with the following fields:
%     - el0            (1,6)  Initial reference orbital elements  (Alfriend format) [a,theta,i,q1,q2,W]
%     - dEl0           (1,6)  Initial orbital element differences (Alfriend format) [a,theta,i,q1,q2,W]
%     - goals           (.)   Goals data structure defining desired relative motion
%     - window          (.)   Data structure defining the desired maneuver window
%     - params          (.)   Data structure defining the several maneuver parameters
%     - deadband       (1,3)  x,y,z dimensions of the position error deadband "box"
%     - noise          (1,4)  Standard deviation of noise for the following sources:
%                          noise(1) - absolute position [m]
%                          noise(2) - absolute velocity [m/s]
%                          noise(3) - relative position [m]
%                          noise(4) - relative velocity [m/s]
%     - nOrbits         (1)   Number of orbits to simulate
%     - nSPO            (1)   Number of simulation points per orbit
%     - distOpt        (1,3)  Disturbance options (flags)
%                          (1) solar:  whether to simulate with solar pressure or not
%                          (2) drag:   whether to simulate with drag or not
%                          (3) J2:     whether to simulate with J2 or not
%     - mass           (1,2)  Mass of reference and relative [kg]
%     - aera           (1,2)  Cross-sectional area of reference and relative [m^2]
%     - controlMethod   (1)   Which control method to use:
%                           - closed form solution (1)
%                           - linear programming (2)
%-------------------------------------------------------------------------------